@@ -38,13 +38,13 @@ def run_setup():
 
 class FoodParser():
     def __init__(self):
-        self.__version__ = '0.1.5'
+        self.__version__ = '0.1.6'
         self.wnl = WordNetLemmatizer()
         self.spell = SpellChecker()
         return
 
     def test(self):
-        str_ = pkg_resources.resource_string(__name__, "test.txt")
+        str_ = pkg_resources.resource_string(__name__, "data/test.txt")
         print(test.txt)
 
     def initialization(self):
